16.55. cdist-type__hostname(7) — cdist 6.1.1 documentation

# 16.55. cdist-type__hostname(7)

## 16.55.1. NAME

cdist-type__hostname - Set the hostname

## 16.55.2. DESCRIPTION

Sets the hostname on various operating systems.

Tip: For advice on choosing a hostname, see RFC 1178.

## 16.55.3. REQUIRED PARAMETERS

None.

## 16.55.4. OPTIONAL PARAMETERS

name
  The hostname to set. Defaults to the first segment of __target_host (${__target_host%%.*})

## 16.55.5. MESSAGES

changed
  Changed the hostname

## 16.55.6. EXAMPLES

    # take hostname from __target_host
    __hostname

    # set hostname explicitly
    __hostname --name some-static-hostname

## 16.55.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.55.8. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.